
package io.zipcoder.casino;

import java.util.ArrayList;
import java.util.Arrays;


public class BlackJack {


    private ArrayList<Card> playerHand = new ArrayList<Card>();
    private ArrayList<Card> dealerHand = new ArrayList<Card>();
    private int currentBet;
    private boolean playingBJ = false;
    private boolean playingHands = true;
    private boolean askToPlayAgain = false;
    boolean dStay = true;
    boolean pStay = false;
    private CardDeck deck = new CardDeck();
    private static Player player;

    public BlackJack() {
        this.player = new Player("Eugene");
    }

    public void start() {
        playingBJ = true;
        this.deck.shuffle();
    }

    private void dealToPlayerHand(int amountOfCards) {
        for (int i = 0; i < amountOfCards; i++) {
            this.playerHand.add(deck.draw());
        }
    }

    private void dealToDealerHand(int amountOfCards) {
        for (int i = 0; i < amountOfCards; i++) {
            this.dealerHand.add(deck.draw());
        }
    }

    private void setPlayingHands(boolean bool) {
        this.playingHands = bool;
    }

    private String getPlayerHand() {

        return Arrays.toString(this.playerHand.toArray());
    }

    private String getDealerHand() {
        return Arrays.toString(this.dealerHand.toArray());
    }

    private String showDealerHand() {
        Card[] filteredArray = this.dealerHand.toArray(new Card[this.dealerHand.size()]);
        filteredArray[0] = new Card();
        return Arrays.toString(filteredArray);
    }

    private void setCurrentBet(int bet) {
        this.currentBet = bet;
    }

    private void setAskToPlayAgain(boolean bool) {
        this.askToPlayAgain = bool;
    }

    private void resetHands() {
        this.playerHand = new ArrayList<Card>();
        this.dealerHand = new ArrayList<Card>();
    }

    private void startHands() {
        this.deck = new CardDeck();
        this.deck.shuffle();
        resetHands();
        dealToPlayerHand(2);
        dealToDealerHand(2);
    }

    private void startNextHand() {
        setCurrentBet(0);
        setAskToPlayAgain(true);
        setPlayingHands(false);
    }

    private int getCardValue(Card card) {
        Rank rank = card.getRank();
        int calcValue = 0;
        switch (rank) {
            case ACE:
                calcValue = 11;
                break;
            case TWO:
                calcValue = 2;
                break;
            case THREE:
                calcValue = 3;
                break;
            case FOUR:
                calcValue = 4;
                break;
            case FIVE:
                calcValue = 5;
                break;
            case SIX:
                calcValue = 6;
                break;
            case SEVEN:
                calcValue = 7;
                break;
            case EIGHT:
                calcValue = 8;
                break;
            case NINE:
                calcValue = 9;
                break;
            case TEN:
                calcValue = 10;
                break;
            case JACK:
            case QUEEN:
            case KING:
                calcValue = 10;
                break;
        }
        return calcValue;
    }

    private int calcHand(ArrayList<Card> hand) {
        int totalScore = 0;
        int aceCount = 0;
        for (int i = 0; i < hand.size(); i++) {
            totalScore += getCardValue(hand.get(i));
            if(getCardValue(hand.get(i)) == 11){
                aceCount++;
            }
        }
        if(totalScore > 21 && aceCount > 0){
            totalScore -= 10;
            aceCount--;
        }
        return totalScore;
    }

    private void playerBust() {
        Console.output("Dealer wins! You bust.");
        player.subtractFromBankroll(currentBet);
        pStay = true;
        startNextHand();
    }

    private void dealerBust() {
        Console.output("Dealer busts! You win");
        player.addToBankroll(currentBet);
        startNextHand();
        dStay = true;
    }

    private void delay(int time) {
        try {
            Thread.sleep(time);
        } catch (InterruptedException ex) {
            Thread.currentThread().interrupt();
        }
    }

    private void playerHits() {
        dealToPlayerHand(1);
        delay(1500);
        Console.output("You now have:\n" + getPlayerHand() + " for a total of " + calcHand(playerHand));
        if (calcHand(playerHand) > 21) {
            delay(1500);
            playerBust();
        }
    }

    private void playerDoubles() {
        Console.output("Doubling down...");
        delay(1500);
        setCurrentBet(currentBet * 2);
        dealToPlayerHand(1);
        pStay = true;
        dStay = false;
        Console.output("You now have:\n" + getPlayerHand() + " for a total of " + calcHand(playerHand));
        if (calcHand(playerHand) > 21) {
            delay(1500);
            playerBust();
            dStay = true;
        }
    }

    private void playerStays() {
        Console.output("Player Stays.");
        delay(1500);
        pStay = true;
        dStay = false;
    }

    private void dealerHits() {
        dealToDealerHand(1);
        delay(1500);
        Console.output("Dealer hits.");
        delay(1500);
        Console.output("Dealer has: " + getDealerHand() + " for a total of " + calcHand(dealerHand));
    }

    private void dealerStays() {
        delay(1500);
        Console.output("Dealer stays.");
        dStay = true;
    }

    private void dealerBj() {
        delay(1500);
        Console.output("Dealer has BlackJack! You lose!");
        player.subtractFromBankroll(currentBet);
        startNextHand();
    }

    private void playerBj() {
        delay(1500);
        Console.output("You have BlackJack! You win!");
        player.addToBankroll((currentBet * 3) / 2);
        startNextHand();
    }

    private void playerPush(){
        delay(1500);
        Console.output("It's a push!");
        startNextHand();
    }

    private void playerWins(){
        delay(1500);
        Console.output("You win!");
        player.addToBankroll(currentBet);
    }

    private void dealerWins(){
        delay(1500);
        Console.output("You lose!");
        player.subtractFromBankroll(currentBet);

    }

    private void newDeal(){
        Console.output("You have " + player.getBankroll() + " in your players account.");
        delay(1000);
        int bet = Console.numberFromString(Console.askForInput("How much would you like to bet? "));
        setCurrentBet(bet);
        Console.output("Dealing...");
        delay(2000);
        startHands();
        Console.output("You have: " + getPlayerHand() + " for a total of " + calcHand(playerHand));
        Console.output("Dealer is showing: " + showDealerHand());
        pStay = false;
    }

    public void startGame() {
        start();
        Console.output("Welcome. I am your dealer Vince.");
        delay(1000);
        Console.output("Starting BlackJack...");
        delay(1000);
        while (playingBJ) {
            while (askToPlayAgain) {
                delay(1000);
                String answer = Console.askForInput("Would you like to play again? (Y/N)");
                if (answer.equals("y")) {
                    setPlayingHands(true);
                    setAskToPlayAgain(false);
                } else {
                    setPlayingHands(false);
                    setAskToPlayAgain(false);
                }
            }
            while (playingHands) {
                newDeal();
                while ((calcHand(playerHand) < 21 && calcHand(dealerHand) < 21) && pStay == false) {
                    delay(1500);
                    String action = Console.askForInput("Hit, Stay, Double Down? (H/S/DD)");
                    if (action.equals("h")) {
                        playerHits();
                    }
                    if (action.equals("dd")) {
                        playerDoubles();
                    }
                    if (action.equals("s")) {
                        playerStays();
                    }
                }
                Console.output("Dealer has: " + getDealerHand() + " for a total of " + calcHand(dealerHand));
                while (!dStay) {
                    if (calcHand(dealerHand) > 21) {
                        dealerBust();
                    }
                    if (calcHand(dealerHand) < 17) {
                        dealerHits();

                    } else if (calcHand(dealerHand) >= 17 && calcHand(dealerHand) <= 21) {
                        dealerStays();
                    }
                }
                if (calcHand(dealerHand) == 21) {
                    dealerBj();
                } else if (calcHand(playerHand) == 21) {
                    playerBj();
                } else if (calcHand(playerHand) == calcHand(dealerHand)) {
                    playerPush();
                } else if ((calcHand(playerHand) < 22) && (calcHand(playerHand) > calcHand(dealerHand))) {
                    playerWins();
                } else if ((calcHand(dealerHand) < 22) && (calcHand(dealerHand) > calcHand(playerHand))) {
                    dealerWins();
                }
                startNextHand();

            }
        }
    }
}
>>>>>>> newblackjack
